PROCEDURE Err_Box
PARAMETERS pc_msg, pl_shadow
*----------------------------------------------------------------------------
* NAME
*   Err_Box - Display an error box
*
* SYNOPSIS
*   DO Err_Box WITH <pc_msg>
*
* DESCRIPTION
*   Err_Box will display the <pc_msg> string in a box and prompt the
*   user to press any key to continue processing.  Err_Box will display
*   the message based on the length of <pc_msg>.
*
* PARAMETERS
*   pc_msg    = the error message to display in the box.  If the length is
*               greater than 76, the trailing part is chopped off.
*   pl_shadow = .t. for shadow effect, or .f. for normal
*
* EXAMPLE
*   DO Err_Box WITH "Incorrect window size"
*   Displays the message in a window as follows at row 9 on the screen:
*                      +------------------------------+
*                      |                              |
*                      |    Incorrect window size     |
*                      |                              |
*                      | Press any key to continue... |
*                      |                              |
*                      +------------------------------+
*   Note that the width of the window will increase to accommodate a longer
*   message string.
*
* LIMITATIONS
*   Truncates the message after 76 characters.  Assumes an 80 character
*   wide screen.  Looks best with SET CURSOR OFF.
*
*----------------------------------------------------------------------------

  PRIVATE lc_anykey, lc_msg, lc_msglen, lc_win, ln_press, ln_width, ll_trap,;
          ll_escape

  lc_anykey = [Press any key to continue...]
  ln_press  = LEN( lc_anykey )
  lc_win = WINDOW()                     && Currently activated window if any
  lc_msg = LTRIM( RTRIM( pc_msg ) )     && Trimmed message
  ln_msglen = LEN( lc_msg )             && Trimmed length of message
  ln_width = 0                          && Width of display area in window.
  ll_escape = SET("ESCAPE") = "ON"
  IF TYPE( "FXL_DEV" ) = "L" .AND. FXL_DEV
    SET ESCAPE ON
  ELSE
    SET ESCAPE OFF
  ENDIF

  *-- Determine the width needed for the window:
  IF ln_msglen <= ln_press
    ln_width = ln_press
  ELSE
    *-- Make sure the message fits in the window:
    IF ln_msglen > 76
      lc_msg = LEFT( lc_msg, 76 )
      ln_msglen = 76
    ENDIF
    ln_width = ln_msglen
  ENDIF
  lc_CoMess = ColorChk( "M" )
  DEFINE WINDOW Err_Box FROM 9, ((76 - ln_width) + .5) / 2 ;
                TO 15, (ln_width + 83) / 2 DOUBLE ;
     COLOR &lc_CoMess

  ln_width = ( ln_width + 2 )

  *-- Display the message and prompt to the window and wait for a key press
  IF pl_shadow
    SAVE SCREEN TO Err_Box
    DO ShadowG WITH 9, ;
                    ((76 - ln_width) + .5) / 2, ;
                    15, ;
                    (ln_width + 83) / 2
  ENDIF
  ACTIVATE WINDOW Err_Box
  @ 1, ( ln_width - ln_msglen ) / 2 SAY lc_msg
  @ 3, ( ln_width - ln_press ) / 2 SAY lc_anykey
  SET CONSOLE OFF                       && For mouse click recognition
  WAIT
  SET CONSOLE ON

  *-- Clean up the window display and reactivate the previous window
  RELEASE WINDOW Err_Box
  IF ISBLANK( lc_win )
    ACTIVATE SCREEN
  ENDIF
  IF pl_shadow
    RESTORE SCREEN FROM Err_Box
    RELEASE SCREEN Err_Box
  ENDIF

  IF ll_escape
    SET ESCAPE ON
  ELSE
    SET ESCAPE OFF
  ENDIF

RETURN
*-- EOP: Err_Box WITH pc_msg



